/******************************************************************************
 *            g_echecs_init.c                                                 *
 *                                                                            *
 *  Copyright  2006  gerald.dumas                                             *
 *  linechec@laposte.net                                                      *
 ******************************************************************************
 *                                                                            *
 *  This program is free software; you can redistribute it and/or modify      *
 *  it under the terms of the GNU General Public License as published by      *
 *  the Free Software Foundation; either version 2 of the License, or         *
 *  any later version.                                                        *
 *                                                                            *
 *  This program is distributed in the hope that it will be useful,           *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
 *  GNU General Public License for more details.                              *
 *                                                                            *
 *  You should have received a copy of the GNU General Public License         *
 *  along with this program; if not, write to the Free Software               *
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.*
 ******************************************************************************/

/* 	Fonction d'initialisation des différentes variables nécessaires
	à l'utilisation de l'interface graphique*/

#include "g_echecs_init.h"

gboolean g_initialisation_jeu()
{
	GtkListStore *coup_affiche;
	coup_affiche=(GtkListStore*)
								(gtk_data_list_get_by_name(widget_list, "coup affiche"));
	GtkWidget *Zone_dessin;
	Zone_dessin=(GtkWidget*)
								(gtk_data_list_get_by_name(widget_list, "Zone dessin"));
	GtkWidget *bouton_debut;
	bouton_debut=(GtkWidget*)
								(gtk_data_list_get_by_name(widget_list, "bouton debut"));
	GtkWidget *bouton_recul;
	bouton_recul=(GtkWidget*)
								(gtk_data_list_get_by_name(widget_list, "bouton recul"));
	GtkWidget *bouton_avance;
	bouton_avance=(GtkWidget*)
								(gtk_data_list_get_by_name(widget_list, "bouton avance"));
	GtkWidget *bouton_dernier_coup;
	bouton_dernier_coup=(GtkWidget*)
								(gtk_data_list_get_by_name(widget_list, "bouton dernier coup"));
	GtkWidget *cadre_pieces_prises;
	cadre_pieces_prises=(GtkWidget*)
								(gtk_data_list_get_by_name(widget_list, "cadre pieces prises"));
	GtkWidget *table_pieces_prises;
	table_pieces_prises=(GtkWidget*)
								(gtk_data_list_get_by_name(widget_list, "table pieces prises"));
	GtkWidget *barre_outils;
	barre_outils=(GtkWidget*)
								(gtk_data_list_get_by_name(widget_list, "barre outils"));

	vider_liste(liste_coups_jouables);
	liste_coups_jouables=NULL;
	liste_coups_jouables=echec_init(liste_coups_jouables);
	// On efface la liste des coups joués
	gtk_list_store_clear(coup_affiche);
	// Initialisation du pointeur de navigation
	g_position_courante_navigation=1;

	// On interdit la navigation puisqu'il n'y a plus de coup
	gtk_widget_set_sensitive(bouton_debut, FALSE); // insensible au début de la partie
	gtk_widget_set_sensitive(bouton_recul, FALSE); // insensible au début de la partie
	gtk_widget_set_sensitive(bouton_avance, FALSE); // insensible au début de la partie
	gtk_widget_set_sensitive(bouton_dernier_coup, FALSE); // insensible au début de la partie
	gtk_widget_set_sensitive (GTK_WIDGET(gtk_toolbar_get_nth_item
																			(GTK_TOOLBAR (barre_outils), 6)), FALSE);

	// On autorise l'utilisation de l'échiquier
	gtk_widget_set_sensitive(Zone_dessin, TRUE);

	// On efface les pièces prises
	gtk_widget_destroy(table_pieces_prises);
	widget_list=gtk_data_list_remove_by_name(widget_list,"table pieces prises");

	// Création d'une table pour afficher les pièces prises.
	// Cette table est dessous le cadre_partie qui affiche les coups joués.
	table_pieces_prises=gtk_table_new(4,8,TRUE);
	widget_list=gtk_data_list_add_by_name(widget_list, table_pieces_prises,
																												"table pieces prises");
	gtk_widget_set_size_request(table_pieces_prises,180,80);
	// Création d'un cadre contenant le tableau des pieces prises
	gtk_container_add(GTK_CONTAINER(cadre_pieces_prises),table_pieces_prises);
	gtk_widget_show_all(table_pieces_prises);

	// On désactive le bouton enregistrer
	gtk_widget_set_sensitive (GTK_WIDGET(gtk_toolbar_get_nth_item
																		(GTK_TOOLBAR (barre_outils), 3)), FALSE);

	// On force la mis à jour de l'affichage de l'échiquier
	gtk_widget_queue_draw(Zone_dessin);
	return TRUE;
}

GtkWidget *g_echecs_init(GtkWidget *splash_window)
{
	register gint x,y;
	gchar *chemin=NULL;		// Chemin principal des différents pixmaps
	gchar *tmp, *tmp2;
	GtkWidget *box;
	GdkPixbuf *icone_appli;

	// initialisation des différentes icônes
	tmp=g_key_file_get_string(key_file_config, "DIRECTORY", "install", NULL);
	if (strcmp(tmp, "/usr/bin")==0)
	{
		g_free(tmp);
		// DEBUG by xcfaudio: changing the order of directories
		// tmp=g_strdup("/usr/share/linechec/pixmaps");
		tmp=g_strdup("/usr/share/pixmaps/linechec");
	}
	else
	{
		g_free(tmp);
		tmp=g_strdup_printf("%s/pixmaps",g_key_file_get_string(key_file_config,
																							"DIRECTORY", "install", NULL));
	}

	tmp2=g_key_file_get_string(key_file_config,
															"DIRECTORY", "chess_pixmaps", NULL);

	for (x=0; x<7; x++)
	{
		for (y=0; y<2; y++)
		{
			// Chargement de l'image dans un GtkImage;
			chemin=g_strdup_printf("%s/echiquier/%s/%s",tmp,tmp2,table_nom_images[x][y]);
			buf_images[x][y]=gdk_pixbuf_new_from_file_at_scale(chemin, TAILLE_PIECE,
																										TAILLE_PIECE, FALSE, NULL);
			g_free(chemin);
		}
	}
	chemin=g_strdup_printf("%s/linechec.xpm",tmp);
	icone_appli=gdk_pixbuf_new_from_file(chemin, NULL);
	widget_list=gtk_data_list_add_by_name(widget_list, icone_appli,"icone_appli");
	g_free(chemin);
	g_free(tmp2);

	// Affichage d'un splashscreen
	chemin=g_strdup_printf("%s/linechec_bandeau.jpg",tmp);
	splash_window=gtk_window_new(GTK_WINDOW_TOPLEVEL);
	gtk_window_set_modal(GTK_WINDOW(splash_window), TRUE);
	gtk_window_set_icon(GTK_WINDOW(splash_window),icone_appli);
	gtk_window_set_decorated(GTK_WINDOW(splash_window), FALSE);
	gtk_window_set_position(GTK_WINDOW(splash_window), GTK_WIN_POS_CENTER);
	box=gtk_vbox_new(FALSE,4);
	gtk_container_add(GTK_CONTAINER(splash_window), box);
	gtk_box_pack_start_defaults(GTK_BOX(box), gtk_image_new_from_file(chemin));
	g_free(chemin);
	g_free(tmp);

	gtk_box_pack_start_defaults(GTK_BOX(box),
														gtk_label_new("Création de la fenêtre principale"));
	gtk_widget_show_all(splash_window);
	while ( gtk_events_pending() ) gtk_main_iteration();
	return splash_window;
}
